@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.12 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2022, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: tpih2.c,v 7.12 2022/09/09 04:57:58 mcalabre Exp $
+  $Id: tpih2.c,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *=============================================================================
 *
 * tpih2 tests wcspih(), the WCS FITS parser for image headers, by reading a
@@ -32,11 +32,15 @@
 *
 *---------------------------------------------------------------------------*/
 
+// Needed to get nanosleep() from time.h.
+#define _POSIX_C_SOURCE 199309L
+
 #include <wcsconfig_tests.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 
 #if defined HAVE_CFITSIO && defined DO_CFITSIO
 #include <fitsio.h>
@@ -189,6 +193,10 @@ int main()
     // Draw the frame.
     cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
 
+    // Allow 500ms to view the plot on fast machines.
+    struct timespec nano = {(time_t)0, 500000000L};
+    nanosleep(&nano, 0x0);
+
     cpgpage();
   }
 
