@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.12 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2022, Mark Calabretta
+  WCSLIB 8.1 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2023, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -19,7 +19,7 @@
 
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: wcs_f.c,v 7.12 2022/09/09 04:57:58 mcalabre Exp $
+  $Id: wcs_f.c,v 8.1 2023/07/05 17:12:07 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -145,6 +145,12 @@
 #define WCS_CRLN_OBS 169
 #define WCS_HGLN_OBS 170
 #define WCS_HGLT_OBS 171
+#define WCS_A_RADIUS 172
+#define WCS_B_RADIUS 173
+#define WCS_C_RADIUS 174
+#define WCS_BLON_OBS 175
+#define WCS_BLAT_OBS 176
+#define WCS_BDIS_OBS 177
 
 #define WCS_NTAB     200
 #define WCS_NWTB     201
@@ -155,12 +161,13 @@
 #define WCS_LNG      206
 #define WCS_LAT      207
 #define WCS_SPEC     208
-#define WCS_CUBEFACE 209
-#define WCS_TYPES    210
-#define WCS_LIN      211
-#define WCS_CEL      212
-#define WCS_SPC      213
-#define WCS_ERR      214
+#define WCS_TIME     209
+#define WCS_CUBEFACE 210
+#define WCS_TYPES    211
+#define WCS_LIN      212
+#define WCS_CEL      213
+#define WCS_SPC      214
+#define WCS_ERR      215
 
 //----------------------------------------------------------------------------
 
@@ -424,6 +431,12 @@ int wcsput_(
   case WCS_CRLN_OBS:
   case WCS_HGLN_OBS:
   case WCS_HGLT_OBS:
+  case WCS_A_RADIUS:
+  case WCS_B_RADIUS:
+  case WCS_C_RADIUS:
+  case WCS_BLON_OBS:
+  case WCS_BLAT_OBS:
+  case WCS_BDIS_OBS:
     if (wcsp->aux == 0x0) {
       if (wcsauxi(1, wcsp)) {
         return 2;
@@ -446,6 +459,24 @@ int wcsput_(
     case WCS_HGLT_OBS:
       wcsp->aux->hglt_obs = *dvalp;
       break;
+    case WCS_A_RADIUS:
+      wcsp->aux->a_radius = *dvalp;
+      break;
+    case WCS_B_RADIUS:
+      wcsp->aux->b_radius = *dvalp;
+      break;
+    case WCS_C_RADIUS:
+      wcsp->aux->c_radius = *dvalp;
+      break;
+    case WCS_BLON_OBS:
+      wcsp->aux->blon_obs = *dvalp;
+      break;
+    case WCS_BLAT_OBS:
+      wcsp->aux->blat_obs = *dvalp;
+      break;
+    case WCS_BDIS_OBS:
+      wcsp->aux->bdis_obs = *dvalp;
+      break;
     }
 
     break;
@@ -775,6 +806,24 @@ int wcsget_(const int *wcs, const int *what, void *value)
   case WCS_HGLT_OBS:
     *dvalp = wcsp->aux ? wcsp->aux->hglt_obs : UNDEFINED;
     break;
+  case WCS_A_RADIUS:
+    *dvalp = wcsp->aux ? wcsp->aux->a_radius : UNDEFINED;
+    break;
+  case WCS_B_RADIUS:
+    *dvalp = wcsp->aux ? wcsp->aux->b_radius : UNDEFINED;
+    break;
+  case WCS_C_RADIUS:
+    *dvalp = wcsp->aux ? wcsp->aux->c_radius : UNDEFINED;
+    break;
+  case WCS_BLON_OBS:
+    *dvalp = wcsp->aux ? wcsp->aux->blon_obs : UNDEFINED;
+    break;
+  case WCS_BLAT_OBS:
+    *dvalp = wcsp->aux ? wcsp->aux->blat_obs : UNDEFINED;
+    break;
+  case WCS_BDIS_OBS:
+    *dvalp = wcsp->aux ? wcsp->aux->bdis_obs : UNDEFINED;
+    break;
 
   case WCS_NTAB:
     *ivalp = wcsp->ntab;
@@ -803,6 +852,9 @@ int wcsget_(const int *wcs, const int *what, void *value)
   case WCS_SPEC:
     *ivalp = wcsp->spec + 1;
     break;
+  case WCS_TIME:
+    *ivalp = wcsp->time + 1;
+    break;
   case WCS_CUBEFACE:
     *ivalp = wcsp->cubeface;
     break;
